import { defineComponent, $prefix, directive, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/multi-select/vue';
import { iconChevronDown, iconSearch } from '@opentinyvue/vue-icon';
import Button from '@opentinyvue/vue-button';
import Input from '@opentinyvue/vue-input';
import Mask from '@opentinyvue/vue-mask';
import MultiSelectItem from '@opentinyvue/vue-multi-select-item';
import Wheel from '@opentinyvue/vue-wheel';
import Clickoutside from '@opentinyvue/vue-renderless/common/deps/clickoutside';
import { t } from '@opentinyvue/vue-locale';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "MultiSelect",
  components: {
    IconChevronDown: iconChevronDown(),
    IconSearch: iconSearch(),
    TinyButton: Button,
    TinyWheel: Wheel,
    TinyMask: Mask,
    TinyMultiSelectItem: MultiSelectItem,
    TinyInput: Input
  },
  directives: directive({
    Clickoutside
  }),
  props: {
    dataSource: {
      type: Array,
      default: function _default() {
        return [];
      }
    },
    modelValue: {
      type: [String, Array],
      default: ""
    },
    searchValue: {
      type: String,
      default: ""
    },
    defaultSelectedArray: {
      type: Array,
      default: function _default2() {
        return [];
      }
    },
    filterable: {
      type: Boolean,
      default: false
    },
    searchPlaceholder: {
      type: String,
      default: function _default3() {
        return t("ui.search.placeholder");
      }
    },
    type: {
      type: String,
      default: "list"
    },
    disabled: {
      type: Boolean,
      default: false
    },
    mask: {
      type: Boolean,
      default: false
    },
    maskOptions: {
      type: Object,
      default: function _default4() {
        return {};
      }
    }
  },
  emits: ["update:modelValue", "update:searchValue", "item-click"],
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm$dataSource$_vm$st, _vm$dataSource$_vm$st2;
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    directives: [{
      name: "clickoutside",
      rawName: "v-clickoutside",
      value: _vm.handleClose,
      expression: "handleClose"
    }],
    staticClass: "tiny-mobile-multi-select"
  }, [_c("div", {
    ref: "headerBox",
    class: ["tiny-mobile-multi-select__header", {
      "show-search": _vm.filterable,
      "is-searching": _vm.state.isSearching,
      "is-disabled": _vm.disabled
    }]
  }, [!_vm.state.isSearching ? [_c("div", {
    staticClass: "tiny-mobile-multi-select__header-item-box"
  }, _vm._l(_vm.dataSource, function(item, index) {
    var _vm$state$headerInfo$, _vm$state$headerInfo$2, _vm$state$headerInfo$3, _vm$state$headerInfo$4;
    return _c("div", {
      key: index,
      class: ["tiny-mobile-multi-select__header-item", {
        "item-disabled": item.disabled
      }],
      style: _vm.state.labelsStyle[index],
      on: {
        "click": function click($event) {
          return _vm.handleClick(index);
        }
      }
    }, [_c("div", {
      class: ["tiny-mobile-multi-select__header__label", (_vm$state$headerInfo$ = _vm.state.headerInfo[index]) !== null && _vm$state$headerInfo$ !== void 0 && _vm$state$headerInfo$.isSelected ? "tiny-mobile-multi-select__header__active" : ""]
    }, [_vm._v(" " + _vm._s((_vm$state$headerInfo$2 = _vm.state.headerInfo[index]) === null || _vm$state$headerInfo$2 === void 0 ? void 0 : _vm$state$headerInfo$2.title) + " ")]), _c("div", {
      class: ["tiny-mobile-multi-select__header__icon", (_vm$state$headerInfo$3 = _vm.state.headerInfo[index]) !== null && _vm$state$headerInfo$3 !== void 0 && _vm$state$headerInfo$3.isSelected ? "tiny-mobile-multi-select__header__active" : ""],
      style: {
        transform: (_vm$state$headerInfo$4 = _vm.state.headerInfo[index]) !== null && _vm$state$headerInfo$4 !== void 0 && _vm$state$headerInfo$4.isUP ? "rotate(180deg)" : "none"
      }
    }, [_c("IconChevronDown")], 1)]);
  }), 0), _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.filterable && _vm.state.showOptions,
      expression: "filterable && state.showOptions"
    }],
    staticClass: "tiny-mobile-multi-select__header-search-icon",
    on: {
      "click": _vm.handleSearchBtnClick
    }
  }, [_c("IconSearch")], 1)] : [_c("div", {
    staticClass: "tiny-mobile-multi-select__header-search"
  }, [_c("tiny-input", {
    ref: "searchInput",
    attrs: {
      "type": "text",
      "placeholder": _vm.searchPlaceholder
    },
    on: {
      "input": _vm.handleSearchInput
    },
    scopedSlots: _vm._u([{
      key: "prefix",
      fn: function fn() {
        return [_c("IconSearch", {
          staticClass: "tiny-mobile-multi-select__header-prefix-icon"
        })];
      },
      proxy: true
    }]),
    model: {
      value: _vm.state.searchValue,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "searchValue", $$v);
      },
      expression: "state.searchValue"
    }
  })], 1), _c("div", {
    staticClass: "tiny-mobile-multi-select__header-cancel-btn",
    on: {
      "click": _vm.handleSearchBtnClick
    }
  }, [_vm._v(" " + _vm._s(_vm.t("ui.base.cancel")) + " ")])]], 2), _c("tiny-mask", {
    attrs: {
      "visible": _vm.state.showMask
    },
    on: {
      "click": _vm.handleClose
    }
  }), _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.showOptions,
      expression: "state.showOptions"
    }],
    class: ["tiny-mobile-multi-select__content", !((_vm$dataSource$_vm$st = _vm.dataSource[_vm.state.headerIndex]) !== null && _vm$dataSource$_vm$st !== void 0 && _vm$dataSource$_vm$st.hasFooter) ? "noFooter" : ""]
  }, [_vm.type === "list" ? _c("div", {
    staticClass: "tiny-mobile-multi-select__option-list"
  }, _vm._l(_vm.state.currentOptions, function(item, index) {
    return _c("tiny-multi-select-item", {
      key: index,
      attrs: {
        "option": item
      }
    });
  }), 1) : _c("tiny-wheel", {
    attrs: {
      "data-source": _vm.state.wheelData,
      "default-selected-indexs": _vm.state.defaultSelectedIndexs,
      "has-footer": (_vm$dataSource$_vm$st2 = _vm.dataSource[_vm.state.headerIndex]) === null || _vm$dataSource$_vm$st2 === void 0 ? void 0 : _vm$dataSource$_vm$st2.hasFooter
    },
    on: {
      "change": _vm.wheelChange,
      "click-wheel-item": _vm.clickWheelItem
    }
  }), _vm._t("footer", function() {
    var _vm$dataSource$_vm$st3;
    return [_c("div", {
      directives: [{
        name: "show",
        rawName: "v-show",
        value: _vm.state.showOptions && ((_vm$dataSource$_vm$st3 = _vm.dataSource[_vm.state.headerIndex]) === null || _vm$dataSource$_vm$st3 === void 0 ? void 0 : _vm$dataSource$_vm$st3.hasFooter),
        expression: "state.showOptions && dataSource[state.headerIndex]?.hasFooter"
      }],
      staticClass: "tiny-mobile-multi-select__footer"
    }, [_c("tiny-button", {
      attrs: {
        "round": "",
        "size": "large",
        "type": "secondary"
      },
      on: {
        "click": _vm.reset
      }
    }, [_vm._v(_vm._s(_vm.t("ui.base.reset")))]), _c("tiny-button", {
      attrs: {
        "round": "",
        "size": "large",
        "type": "primary"
      },
      on: {
        "click": _vm.confirm
      }
    }, [_vm._v(_vm._s(_vm.t("ui.button.confirm")))])], 1)];
  })], 2)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobile as default };
